-- SPDX-License-Identifier: CC0-1.0

let Genode = env:DHALL_GENODE

let os = env:OS_MANIFEST

let tests = env:SOLO5_TEST_MANIFEST

in  { config =
        Genode.Init::{
        , children =
            toMap
              { nic =
                  Genode.Init.Start::{
                  , binary = "nic_loopback"
                  , provides = [ "Nic" ]
                  }
              , bridge =
                  Genode.Init.Start::{
                  , binary = "nic_bridge"
                  , resources = { caps = 200, ram = Genode.units.MiB 6 }
                  , provides = [ "Nic" ]
                  , routes = [ Genode.ServiceRoute.child "Nic" "nic" ]
                  , config =
                      Some
                        ( Genode.Prelude.XML.text
                            ''
                            <config mac="02:02:02:02:03:00" verbose="no">
                            	<policy label_prefix="solo5" ip_addr="10.0.0.2"/>
                            	<default-policy/>
                            </config>
                            ''
                        )
                  }
              , solo5 =
                  Genode.Init.Start::{
                  , binary = "solo5-test_net"
                  , resources = { caps = 256, ram = Genode.units.MiB 3 }
                  , routes =
                      [ Genode.ServiceRoute.parent "Timer"
                      , Genode.ServiceRoute.child "Nic" "bridge"
                      ]
                  , config =
                      Some
                        ( Genode.Prelude.XML.text
                            "<config><cmdline>limit</cmdline></config>"
                        )
                  }
              , ping =
                  Genode.Init.Start::{
                  , binary = "ping"
                  , exitPropagate = True
                  , resources = { caps = 128, ram = Genode.units.MiB 6 }
                  , routes =
                      [ Genode.ServiceRoute.parent "Timer"
                      , Genode.ServiceRoute.child "Nic" "bridge"
                      ]
                  , config =
                      Some
                        ( Genode.Prelude.XML.leaf
                            { name = "config"
                            , attributes =
                                toMap
                                  { interface = "10.0.0.72/24"
                                  , dst_ip = "10.0.0.2"
                                  , period_sec = "1"
                                  , verbose = "no"
                                  }
                            }
                        )
                  }
              }
        }
    , rom =
        Genode.Boot.toRomPaths
          [ os.bin.nic_loopback
          , os.bin.nic_bridge
          , os.bin.ping
          , tests.bin.solo5-test_net
          ]
    }
